@@ -1051,7 +1051,7 @@ int event_execution_loop(void) {
 		/* keep track of the last time */
 		last_time = current_time;
 
-		/* update status information occassionally - NagVis watches the NDOUtils DB to see if Nagios is alive */
+		/* update status information occasionally - NagVis watches the NDOUtils DB to see if Nagios is alive */
 		if((unsigned long)(current_time - last_status_update) > 5) {
 			last_status_update = current_time;
 			update_program_status(FALSE);
@@ -1069,7 +1069,7 @@ int event_execution_loop(void) {
 		last_event = temp_event;
 
 		gettimeofday(&now, NULL);
-		poll_time_ms = tv_delta_msec(&now, event_runtime) - 25;
+		poll_time_ms = tv_delta_msec(&now, event_runtime);
 		if (poll_time_ms < 0)
 			poll_time_ms = 0;
 		else if(poll_time_ms >= 1500)
@@ -1097,9 +1097,9 @@ int event_execution_loop(void) {
 			continue;
 			}
 
-		/* 100 milliseconds allowance for firing off events early */
+		/* 5 milliseconds allowance for firing off events early */
 		gettimeofday(&now, NULL);
-		if (tv_delta_msec(&now, event_runtime) > 100)
+		if (tv_delta_msec(&now, event_runtime) > 5)
 			continue;
 
 		/* move on if we shouldn't run this event */
@@ -1155,7 +1155,7 @@ int handle_timed_event(timed_event *event) {
 	gettimeofday(&tv, NULL);
 	event_runtime = squeue_event_runtime(event->sq_event);
 	latency = (double)(tv_delta_f(event_runtime, &tv));
-	if (latency < 0.0) /* events may run up to 0.1 seconds early */
+	if (latency < 0.0) /* events may run up to 0.005 seconds early */
 		latency = 0.0;
 
 	/* how should we handle the event? */
@@ -1322,6 +1322,11 @@ int handle_timed_event(timed_event *event) {
 			break;
 		}
 
+#ifdef USE_EVENT_BROKER
+	/* send event data to broker */
+	broker_timed_event(NEBTYPE_TIMEDEVENT_END, NEBFLAG_NONE, NEBATTR_NONE, event, NULL);
+#endif
+
 	log_debug_info(DEBUGL_FUNCTIONS, 0, "handle_timed_event() end\n");
 
 	return OK;
@@ -1332,7 +1337,7 @@ int handle_timed_event(timed_event *event) {
 /* The squeue internal event type, declared again here so we can manipulate the
  * scheduling queue without a malloc/free for each add/remove.
  * @todo: Refactor this to not depend so heavily on the event queue
- * implementation, doing so efficiently may require a different sheduling queue
+ * implementation, doing so efficiently may require a different scheduling queue
  * data structure. */
 struct squeue_event {
 	unsigned int pos;
