@@ -2,8 +2,6 @@
  *
  * PERFDATA.C - Performance data routines for Nagios
  *
- * Copyright (c) 2000-2004 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   11-29-2004
  *
  * License:
  *
@@ -29,17 +27,8 @@
 #include "../include/common.h"
 #include "../include/objects.h"
 #include "../include/perfdata.h"
-
-
-/***** IMPLEMENTATION-SPECIFIC HEADER FILES *****/
-
-#ifdef USE_XPDDEFAULT
+#include "../include/macros.h"
 #include "../xdata/xpddefault.h"
-#endif
-
-
-extern int   process_performance_data;
-
 
 
 /******************************************************************/
@@ -47,26 +36,16 @@ extern int   process_performance_data;
 /******************************************************************/
 
 /* initializes performance data */
-int initialize_performance_data(char *config_file){
-
-#ifdef USE_XPDDEFAULT
-	xpddefault_initialize_performance_data(config_file);
-#endif
-
-	return OK;
-        }
+int initialize_performance_data(const char *cfgfile) {
+	return xpddefault_initialize_performance_data(cfgfile);
+	}
 
 
 
 /* cleans up performance data */
-int cleanup_performance_data(char *config_file){
-
-#ifdef USE_XPDDEFAULT
-	xpddefault_cleanup_performance_data(config_file);
-#endif
-
-	return OK;
-        }
+int cleanup_performance_data(void) {
+	return xpddefault_cleanup_performance_data();
+	}
 
 
 
@@ -76,41 +55,37 @@ int cleanup_performance_data(char *config_file){
 
 
 /* updates service performance data */
-int update_service_performance_data(service *svc){
+int update_service_performance_data(service *svc) {
 
 	/* should we be processing performance data for anything? */
-	if(process_performance_data==FALSE)
+	if(process_performance_data == FALSE)
 		return OK;
 
 	/* should we process performance data for this service? */
-	if(svc->process_performance_data==FALSE)
+	if(svc->process_performance_data == FALSE)
 		return OK;
 
 	/* process the performance data! */
-#ifdef USE_XPDDEFAULT
 	xpddefault_update_service_performance_data(svc);
-#endif
 
 	return OK;
-        }
+	}
 
 
 
 /* updates host performance data */
-int update_host_performance_data(host *hst){
+int update_host_performance_data(host *hst) {
 
 	/* should we be processing performance data for anything? */
-	if(process_performance_data==FALSE)
+	if(process_performance_data == FALSE)
 		return OK;
 
 	/* should we process performance data for this host? */
-	if(hst->process_performance_data==FALSE)
+	if(hst->process_performance_data == FALSE)
 		return OK;
 
 	/* process the performance data! */
-#ifdef USE_XPDDEFAULT
 	xpddefault_update_host_performance_data(hst);
-#endif
 
 	return OK;
-        }
+	}
