@@ -86,7 +86,7 @@ const string_value_mapping svm_au_notification_types[] = {
 	{ "hostcustom", AU_NOTIFICATION_HOST_CUSTOM, 
 			"Host Custom" },
 	{ "hostack", AU_NOTIFICATION_HOST_ACK, 
-			"Host Acknowlegement" },
+			"Host Acknowledgement" },
 	{ "hostflapstart", AU_NOTIFICATION_HOST_FLAPPING_START, 
 			"Host Flapping Start" },
 	{ "hostflapstop", AU_NOTIFICATION_HOST_FLAPPING_STOP, 
@@ -100,7 +100,7 @@ const string_value_mapping svm_au_notification_types[] = {
 	{ "custom", AU_NOTIFICATION_SERVICE_CUSTOM, 
 			"Service Custom" },
 	{ "serviceack", AU_NOTIFICATION_SERVICE_ACK, 
-			"Service Acknowlegement" },
+			"Service Acknowledgement" },
 	{ "serviceflapstart", AU_NOTIFICATION_SERVICE_FLAPPING_START, 
 			"Service Flapping Start" },
 	{ "serviceflapstop", AU_NOTIFICATION_SERVICE_FLAPPING_STOP, 
