@@ -59,7 +59,6 @@ char            *action_url_target = NULL;
 
 char            *ping_syntax = NULL;
 
-char            nagios_check_command[MAX_INPUT_BUFFER] = "";
 char            nagios_process_info[MAX_INPUT_BUFFER] = "";
 int             nagios_process_state = STATE_OK;
 
@@ -72,6 +71,7 @@ int             navbar_search_aliases = TRUE;
 
 int		ack_no_sticky  = FALSE;
 int		ack_no_send    = FALSE;
+int		tac_cgi_hard_only = FALSE;
 
 time_t          this_scheduled_log_rotation = 0L;
 time_t          last_scheduled_log_rotation = 0L;
@@ -176,7 +176,6 @@ void reset_cgi_vars(void) {
 		strcat(log_archive_path, "/");
 	strcpy(command_file, get_cmd_file_location());
 
-	strcpy(nagios_check_command, "");
 	strcpy(nagios_process_info, "");
 	nagios_process_state = STATE_OK;
 
@@ -312,12 +311,6 @@ int read_cgi_config_file(const char *filename) {
 		else if(!strcmp(var, "use_authentication"))
 			use_authentication = (atoi(val) > 0) ? TRUE : FALSE;
 
-		else if(!strcmp(var, "nagios_check_command")) {
-			strncpy(nagios_check_command, val, sizeof(nagios_check_command));
-			nagios_check_command[sizeof(nagios_check_command) - 1] = '\x0';
-			strip(nagios_check_command);
-			}
-
 		else if(!strcmp(var, "refresh_rate"))
 			refresh_rate = atoi(val);
 
@@ -447,6 +440,8 @@ int read_cgi_config_file(const char *filename) {
 			ack_no_sticky = (atoi(val) > 0) ? TRUE : FALSE;
 		else if(!strcmp(var, "ack_no_send"))
 			ack_no_send = (atoi(val) > 0) ? TRUE : FALSE;
+		else if(!strcmp(var, "tac_cgi_hard_only"))
+			tac_cgi_hard_only = (atoi(val) > 0) ? TRUE : FALSE;
 		}
 
 	for(p = illegal_output_chars; p && *p; p++)
@@ -495,7 +490,7 @@ int read_main_config_file(const char *filename) {
 		else if(strstr(input, "log_file=") == input) {
 			temp_buffer = strtok(input, "=");
 			temp_buffer = strtok(NULL, "\x0");
-			strncpy(log_file, (temp_buffer == NULL) ? "" : temp_buffer, sizeof(log_file));
+			strncpy(log_file, (temp_buffer == NULL) ? "" : nspath_absolute(temp_buffer, config_file_dir),sizeof(log_file) - 1);
 			log_file[sizeof(log_file) - 1] = '\x0';
 			strip(log_file);
 			}
@@ -1052,7 +1047,7 @@ const char *url_encode(const char *input) {
 		return str;
 
 	len = (int)strlen(input);
-	output_len = (int)sizeof(encoded_url_string[0]);
+	output_len = (int)sizeof(encoded_url_string[i]);
 
 	str[0] = '\x0';
 
@@ -1087,38 +1082,43 @@ const char *url_encode(const char *input) {
 			}
 		}
 
-	str[sizeof(encoded_url_string[0]) - 1] = '\x0';
+	str[sizeof(encoded_url_string[i]) - 1] = '\x0';
+	i = !i;
 
 	return str;
 	}
 
-static char * copy_wc_to_output(wchar_t wc, char *outstp, int output_max) {
+static inline char* encode_character(char in, char *outcp, int output_max)
+{
+	char	*entity = NULL;
+	int		rep_lth, out_len = outcp - encoded_html_string;
 
-	int		wctomb_result;
-	char	mbtemp[ 10];
-
-	wctomb_result = wctomb(mbtemp, wc);
-	if(( wctomb_result > 0) &&
-			((( outstp - encoded_html_string) + wctomb_result) < output_max)) {
-		strncpy( outstp, mbtemp, wctomb_result);
-		outstp += wctomb_result;
-		}
-	return outstp;
+	switch(in) {
+	case '&':	entity = "&amp;";	break;
+	case '"':	entity = "&quot;";	break;
+	case '\'':	entity = "&#39;";	break;
+	case '<':	entity = "&lt;";	break;
+	case '>':	entity = "&gt;";	break;
 	}
 
-static char * encode_character(wchar_t wc, char *outstp, int output_max) {
-
-	char	temp_expansion[11];
-
-	sprintf(temp_expansion, "&#%u;", (unsigned int)wc);
-	if(((outstp - encoded_html_string) + strlen(temp_expansion)) <
-			(unsigned int)output_max) {
-		strncpy(outstp, temp_expansion, strlen( temp_expansion));
-		outstp += strlen( temp_expansion);
+	if (entity) {
+		rep_lth = strlen(entity);
+		if (out_len + rep_lth < output_max) {
+			strcpy(outcp, entity);
+			outcp += rep_lth;
 		}
-	return outstp;
+		return outcp;
 	}
 
+	if (out_len + 6 >= output_max)
+		return outcp;
+
+	sprintf(outcp, "&#%u", (unsigned int)in);
+	outcp += strlen(outcp);
+
+	return outcp;
+}
+
 #define WHERE_OUTSIDE_TAG				0	/* Not in an HTML tag */
 #define WHERE_IN_TAG_NAME				1	/* In HTML tag name (either opening
 												or closing tag) */
@@ -1135,11 +1135,8 @@ static char * encode_character(wchar_t wc, char *outstp, int output_max) {
 char * html_encode(char *input, int escape_newlines) {
 	int 		len;
 	int			output_max;
-	char		*outstp;
-	wchar_t		*wcinput;
-	wchar_t		*inwcp;
-	wchar_t		*tagname = L"";
-	size_t		mbstowcs_result;
+	char		*incp, *outcp;
+	char		*tagname = "";
 	int			x;
 	int			where_in_tag = WHERE_OUTSIDE_TAG; /* Location in HTML tag */
 	wchar_t		attr_value_start = (wchar_t)0;	/* character that starts the 
@@ -1149,135 +1146,124 @@ char * html_encode(char *input, int escape_newlines) {
 	/* we need up to six times the space to do the conversion */
 	len = (int)strlen(input);
 	output_max = len * 6;
-	if(( outstp = encoded_html_string = (char *)malloc(output_max + 1)) == NULL)
+	if(( outcp = encoded_html_string = (char *)malloc(output_max + 1)) == NULL)
 		return "";
 
 	strcpy(encoded_html_string, "");
 
-	/* Convert the string to a wide character string */
-	if(( wcinput = malloc( len * sizeof( wchar_t))) == NULL) {
-		return "";
-		}
-	if((mbstowcs_result = mbstowcs( wcinput, input, len)) == (size_t)-1) {
-		free( wcinput);
-		return "";
-		}
-
 	/* Process all converted characters */
-	for( x = 0, inwcp = wcinput; x < (int)mbstowcs_result && '\0' != *inwcp; 
-			x++, inwcp++) {
+	for (x = 0, incp = input; x < len && *incp; x++, incp++) {
 
 		/* Most ASCII characters don't get encoded */
-		if(( *inwcp  >= 0x20 && *inwcp <= 0x7e) &&
-				( !( '"' == *inwcp || '&' == *inwcp || '\'' == *inwcp ||
-				'<' == *inwcp || '>' == *inwcp))) {
-			outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+		if (*incp >= 0x20 && *incp <= 0x7e && !strchr("'\"&^<>", *incp)) {
+			*outcp++ = *incp;
+
 			switch(where_in_tag) {
+
 			case WHERE_IN_TAG_NAME:
-				switch(*inwcp) {
+				switch(*incp) {
 				case 0x20:
 					where_in_tag = WHERE_IN_TAG_OUTSIDE_ATTRIBUTE;
-					*inwcp = 0;
+					*incp = 0;
 					break;
 				case '!':
 					where_in_tag = WHERE_IN_COMMENT;
 					break;
 					}
 				break;
+
 			case WHERE_IN_TAG_OUTSIDE_ATTRIBUTE:
-				if(*inwcp != 0x20) {
+				if(*incp != 0x20)
 					where_in_tag = WHERE_IN_TAG_IN_ATTRIBUTE_NAME;
-					}
 				break;
+
 			case WHERE_IN_TAG_IN_ATTRIBUTE_NAME:
-				if(*inwcp == '=') {
+				if(*incp == '=')
 					where_in_tag = WHERE_IN_TAG_AT_EQUALS;
-					}
 				break;
+
 			case WHERE_IN_TAG_AT_EQUALS:
-				if(*inwcp != 0x20) {
-					attr_value_start = *inwcp;
+				if(*incp != 0x20) {
+					attr_value_start = *incp;
 					where_in_tag = WHERE_IN_TAG_IN_ATTRIBUTE_VALUE;
-					}
-				break;
-			case WHERE_IN_TAG_IN_ATTRIBUTE_VALUE:
-				if((*inwcp == 0x20) && (attr_value_start != '"') &&
-						(attr_value_start != '\'')) {
-					where_in_tag = WHERE_IN_TAG_OUTSIDE_ATTRIBUTE;
-					}
-				break;
 				}
+				break;
+
+			case WHERE_IN_TAG_IN_ATTRIBUTE_VALUE:
+				if((*incp == 0x20) && (attr_value_start != '"') && (attr_value_start != '\''))
+					where_in_tag = WHERE_IN_TAG_OUTSIDE_ATTRIBUTE;
+				break;
 			}
+		}
 
 		/* Special handling for quotes */
-		else if(FALSE == escape_html_tags && 
-				('"' == *inwcp || '\'' == *inwcp)) {
+		else if(escape_html_tags == FALSE && (*incp == '"' || *incp == '\'')) {
+
 			switch(where_in_tag) {
+
 			case WHERE_OUTSIDE_TAG:
-				if(tag_depth >0) {
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-					}
-				else {
-					outstp = encode_character(*inwcp, outstp, output_max);
-					}
+				if (tag_depth > 0)
+					*outcp++ = *incp;
+				else
+					outcp = encode_character(*incp, outcp, output_max);
 				break;
+
 			case WHERE_IN_COMMENT:
-				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+				*outcp++ = *incp;
 				break;
+
 			case WHERE_IN_TAG_AT_EQUALS:
-				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-				attr_value_start = *inwcp;
+				*outcp++ = *incp;
+				attr_value_start = *incp;
 				where_in_tag = WHERE_IN_TAG_IN_ATTRIBUTE_VALUE;
 				break;
+
 			case WHERE_IN_TAG_IN_ATTRIBUTE_VALUE:
-				if(*(inwcp-1) == '\\') {
-					/* This covers the case where the quote is backslash
-						escaped. */
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-					}
-				else if(attr_value_start == *inwcp) {
+				if(*(incp-1) == '\\')
+					/* This covers the case where the quote is backslash escaped. */
+					*outcp++ = *incp;
+				else if(attr_value_start == *incp) {
 					/* If the quote is the same type of quote that started
 						the attribute value and it is not backslash 
 						escaped, it signals the end of the attribute value */
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+					*outcp++ = *incp;
 					where_in_tag = WHERE_IN_TAG_OUTSIDE_ATTRIBUTE;
-					}
-				else {
-					/* If we encounter an quote that did not start the
-						attribute value and is not backslash escaped, 
-						use it as is */
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-					}
-				break;
-			default:
-				if (tag_depth > 0 && !wcscmp(tagname, L"script"))
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-				else
-					outstp = encode_character(*inwcp, outstp, output_max);
-				break;
 				}
+				else
+					/* If we encounter an quote that did not start the attribute
+						value and is not backslash escaped, use it as is */
+					*outcp++ = *incp;
+				break;
+
+			default:
+				if (tag_depth > 0 && !strcmp(tagname, "script"))
+					*outcp++ = *incp;
+				else
+					outcp = encode_character(*incp, outcp, output_max);
+				break;
 			}
+		}
 
 		/* newlines turn to <BR> tags */
-		else if(escape_newlines == TRUE && '\n' == *inwcp) {
-			strncpy( outstp, "<BR>", 4);
-			outstp += 4;
-			}
+		else if(escape_newlines == TRUE && *incp == '\n') {
+			strncpy( outcp, "<BR>", 4);
+			outcp += 4;
+		}
 
-		else if(escape_newlines == TRUE && '\\' == *inwcp && '\n' == *( inwcp + 1)) {
-			strncpy( outstp, "<BR>", 4);
-			outstp += 4;
-			inwcp++; /* needed so loop skips two wide characters */
-			}
+		else if(escape_newlines == TRUE && *incp == '\\' && *(incp + 1) == '\n') {
+			strncpy( outcp, "<BR>", 4);
+			outcp += 4;
+			incp++; /* needed so loop skips two characters */
+		}
 
 		/* TODO - strip all but allowed HTML tags out... */
-		else if(('<' == *inwcp) && (FALSE == escape_html_tags)) {
+		else if (*incp == '<' && escape_html_tags == FALSE) {
 
 			switch(where_in_tag) {
 			case WHERE_OUTSIDE_TAG:
-				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+				*outcp++ = *incp;
 				where_in_tag = WHERE_IN_TAG_NAME;
-				switch(*(inwcp+1)) {
+				switch(*(incp+1)) {
 				case '/':
 					tag_depth--;
 					break;
@@ -1285,68 +1271,73 @@ char * html_encode(char *input, int escape_newlines) {
 					break;
 				default:
 					tag_depth++;
-					tagname = inwcp + 1;
+					tagname = incp + 1;
 					break;
 					}
 				break;
-			default:
-				if (tag_depth > 0 && !wcscmp(tagname, L"script"))
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-				else
-					outstp = encode_character(*inwcp, outstp, output_max);
-				break;
-				}
-			}
 
-		else if(('>' == *inwcp) && (FALSE == escape_html_tags)) {
+			default:
+				if (tag_depth > 0 && !strcmp(tagname, "script"))
+					*outcp++ = *incp;
+				else
+					outcp = encode_character(*incp, outcp, output_max);
+				break;
+			}
+		}
+
+		else if( *incp == '>' && escape_html_tags == FALSE) {
 
 			switch(where_in_tag) {
 			case WHERE_IN_TAG_NAME:
 			case WHERE_IN_TAG_OUTSIDE_ATTRIBUTE:
 			case WHERE_IN_COMMENT:
 			case WHERE_IN_TAG_IN_ATTRIBUTE_NAME:
-				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+				*outcp++ = *incp;
 				where_in_tag = WHERE_OUTSIDE_TAG;
-				*inwcp = 0;
+				*incp = 0;
 				break;
+
 			case WHERE_IN_TAG_IN_ATTRIBUTE_VALUE:
 				if((attr_value_start != '"') && (attr_value_start != '\'')) {
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+					*outcp++ = *incp;
 					where_in_tag = WHERE_OUTSIDE_TAG;
-					}
-				else {
-					outstp = encode_character(*inwcp, outstp, output_max);
-					}
-				break;
-			default:
-				if (tag_depth > 0 && !wcscmp(tagname, L"script"))
-					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-				else
-					outstp = encode_character(*inwcp, outstp, output_max);
-				break;
 				}
-			}
+				else
+					outcp = encode_character(*incp, outcp, output_max);
+				break;
 
-		/* check_multi puts out a '&ndash' so don't encode the '&' in that case */
-		else if (*inwcp == '&' && escape_html_tags == FALSE) {
-			if (tag_depth > 0 && !wcsncmp(inwcp, L"&ndash", 6))
-				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
-			else
-				outstp = encode_character(*inwcp, outstp, output_max);
-			}
-
-		/* for simplicity, all other chars represented by their numeric value */
-		else {
-			outstp = encode_character(*inwcp, outstp, output_max);
+			default:
+				if (tag_depth > 0 && !strcmp(tagname, "script"))
+					*outcp++ = *incp;
+				else
+					outcp = encode_character(*incp, outcp, output_max);
+				break;
 			}
 		}
 
+		/* check_multi puts out a '&ndash' so don't encode the '&' in that case */
+		else if (*incp == '&' && escape_html_tags == FALSE) {
+			if (tag_depth > 0 && !strcmp(incp, "&ndash"))
+				*outcp++ = *incp;
+			else
+				outcp = encode_character(*incp, outcp, output_max);
+		}
+
+		else if ((unsigned char)*incp > 0x7f)
+			/* pass through UTF-8 characters */
+			*outcp++ = *incp;
+
+		/* for simplicity, all other chars represented by their numeric value */
+		else
+			outcp = encode_character(*incp, outcp, output_max);
+	}
+
 	/* Null terminate the encoded string */
-	*outstp = '\x0';
+	*outcp = '\x0';
 	encoded_html_string[ output_max - 1] = '\x0';
 
 	return encoded_html_string;
-	}
+}
 
 
 
@@ -1359,7 +1350,7 @@ void strip_html_brackets(char *buffer) {
 	if(buffer == NULL || buffer[0] == '\x0')
 		return;
 
-	/* remove all occurances in string */
+	/* remove all occurrences in string */
 	z = (int)strlen(buffer);
 	for(x = 0, y = 0; x < z; x++) {
 		if(buffer[x] == '<' || buffer[x] == '>')
@@ -2122,7 +2113,7 @@ void strip_splunk_query_terms(char *buffer) {
 	if(buffer == NULL || buffer[0] == '\x0')
 		return;
 
-	/* remove all occurances in string */
+	/* remove all occurrences in string */
 	z = (int)strlen(buffer);
 	for(x = 0, y = 0; x < z; x++) {
 		if(buffer[x] == '\'' || buffer[x] == '\"' || buffer[x] == ';' || buffer[x] == ':' || buffer[x] == ',' || buffer[x] == '-' || buffer[x] == '=')
