@@ -2,8 +2,6 @@
  *
  * NEBMODULES.H - Include file for event broker modules
  *
- * Copyright (c) 2002-2006 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   02-27-2006
  *
  * License:
  *
@@ -22,21 +20,20 @@
  *
  *****************************************************************************/
 
-#ifndef _NEBMODULES_H
-#define _NEBMODULES_H
+#ifndef NAGIOS_NEBMODULES_H_INCLUDED
+#define NAGIOS_NEBMODULES_H_INCLUDED
 
-#ifdef __cplusplus
-  extern "C" {
-#endif
+#include "common.h"
+NAGIOS_BEGIN_DECL
 
-/***** MODULE VERSION INFORMATION *****/
+	/***** MODULE VERSION INFORMATION *****/
 
 #define NEB_API_VERSION(x) int __neb_api_version = x;
-#define CURRENT_NEB_API_VERSION    3
+#define CURRENT_NEB_API_VERSION    4
 
 
 
-/***** MODULE INFORMATION *****/
+	/***** MODULE INFORMATION *****/
 
 #define NEBMODULE_MODINFO_NUMITEMS  6
 #define NEBMODULE_MODINFO_TITLE     0
@@ -48,7 +45,7 @@
 
 
 
-/***** MODULE LOAD/UNLOAD OPTIONS *****/
+	/***** MODULE LOAD/UNLOAD OPTIONS *****/
 
 #define NEBMODULE_NORMAL_LOAD       0    /* module is being loaded normally */
 #define NEBMODULE_REQUEST_UNLOAD    0    /* request module to unload (but don't force it) */
@@ -56,7 +53,7 @@
 
 
 
-/***** MODULES UNLOAD REASONS *****/
+	/***** MODULES UNLOAD REASONS *****/
 
 #define NEBMODULE_NEB_SHUTDOWN      1    /* event broker is shutting down */
 #define NEBMODULE_NEB_RESTART       2    /* event broker is restarting */
@@ -69,12 +66,14 @@
 /***** MODULE STRUCTURES *****/
 
 /* NEB module structure */
-typedef struct nebmodule_struct{
+typedef struct nebmodule_struct {
 	char            *filename;
+	char            *dl_file; /* the file we actually loaded */
 	char            *args;
 	char            *info[NEBMODULE_MODINFO_NUMITEMS];
 	int             should_be_loaded;
 	int             is_currently_loaded;
+	int             core_module;
 #ifdef USE_LTDL
 	lt_dlhandle     module_handle;
 	lt_ptr          init_func;
@@ -83,20 +82,13 @@ typedef struct nebmodule_struct{
 	void            *module_handle;
 	void            *init_func;
 	void            *deinit_func;
-#endif
-#ifdef HAVE_PTHREAD_H
-	pthread_t       thread_id;
 #endif
 	struct nebmodule_struct *next;
-        }nebmodule;
-
+	} nebmodule;
 
 
 /***** MODULE FUNCTIONS *****/
-int neb_set_module_info(void *,int,char *);
-
-#ifdef __cplusplus
-  }
-#endif
+int neb_set_module_info(void *, int, char *);
 
+NAGIOS_END_DECL
 #endif
