@@ -151,9 +151,9 @@ int xrddefault_save_state_information(void) {
 
 	/* write file info */
 	fprintf(fp, "info {\n");
-	fprintf(fp, "created=%lu\n", current_time);
+	fprintf(fp, "created=%llu\n", (unsigned long long)current_time);
 	fprintf(fp, "version=%s\n", PROGRAM_VERSION);
-	fprintf(fp, "last_update_check=%lu\n", last_update_check);
+	fprintf(fp, "last_update_check=%llu\n", (unsigned long long)last_update_check);
 	fprintf(fp, "update_available=%d\n", update_available);
 	fprintf(fp, "update_uid=%lu\n", update_uid);
 	fprintf(fp, "last_version=%s\n", (last_program_version == NULL) ? "" : last_program_version);
@@ -209,22 +209,22 @@ int xrddefault_save_state_information(void) {
 		fprintf(fp, "plugin_output=%s\n", (temp_host->plugin_output == NULL) ? "" : temp_host->plugin_output);
 		fprintf(fp, "long_plugin_output=%s\n", (temp_host->long_plugin_output == NULL) ? "" : temp_host->long_plugin_output);
 		fprintf(fp, "performance_data=%s\n", (temp_host->perf_data == NULL) ? "" : temp_host->perf_data);
-		fprintf(fp, "last_check=%lu\n", temp_host->last_check);
-		fprintf(fp, "next_check=%lu\n", temp_host->next_check);
+		fprintf(fp, "last_check=%llu\n", (unsigned long long)temp_host->last_check);
+		fprintf(fp, "next_check=%llu\n", (unsigned long long)temp_host->next_check);
 		fprintf(fp, "check_options=%d\n", temp_host->check_options);
 		fprintf(fp, "current_attempt=%d\n", temp_host->current_attempt);
 		fprintf(fp, "max_attempts=%d\n", temp_host->max_attempts);
-		fprintf(fp, "normal_check_interval=%f\n", temp_host->check_interval);
-		fprintf(fp, "retry_check_interval=%f\n", temp_host->check_interval);
+		fprintf(fp, "check_interval=%f\n", temp_host->check_interval);
+		fprintf(fp, "retry_interval=%f\n", temp_host->retry_interval);
 		fprintf(fp, "state_type=%d\n", temp_host->state_type);
-		fprintf(fp, "last_state_change=%lu\n", temp_host->last_state_change);
-		fprintf(fp, "last_hard_state_change=%lu\n", temp_host->last_hard_state_change);
-		fprintf(fp, "last_time_up=%lu\n", temp_host->last_time_up);
-		fprintf(fp, "last_time_down=%lu\n", temp_host->last_time_down);
-		fprintf(fp, "last_time_unreachable=%lu\n", temp_host->last_time_unreachable);
+		fprintf(fp, "last_state_change=%llu\n", (unsigned long long)temp_host->last_state_change);
+		fprintf(fp, "last_hard_state_change=%llu\n", (unsigned long long)temp_host->last_hard_state_change);
+		fprintf(fp, "last_time_up=%llu\n", (unsigned long long)temp_host->last_time_up);
+		fprintf(fp, "last_time_down=%llu\n", (unsigned long long)temp_host->last_time_down);
+		fprintf(fp, "last_time_unreachable=%llu\n", (unsigned long long)temp_host->last_time_unreachable);
 		fprintf(fp, "notified_on_down=%d\n", flag_isset(temp_host->notified_on, OPT_DOWN));
 		fprintf(fp, "notified_on_unreachable=%d\n", flag_isset(temp_host->notified_on, OPT_UNREACHABLE));
-		fprintf(fp, "last_notification=%lu\n", temp_host->last_notification);
+		fprintf(fp, "last_notification=%llu\n", (unsigned long long)temp_host->last_notification);
 		fprintf(fp, "current_notification_number=%d\n", temp_host->current_notification_number);
 		fprintf(fp, "current_notification_id=%lu\n", temp_host->current_notification_id);
 		fprintf(fp, "notifications_enabled=%d\n", temp_host->notifications_enabled);
@@ -278,27 +278,27 @@ int xrddefault_save_state_information(void) {
 		fprintf(fp, "last_problem_id=%lu\n", temp_service->last_problem_id);
 		fprintf(fp, "current_attempt=%d\n", temp_service->current_attempt);
 		fprintf(fp, "max_attempts=%d\n", temp_service->max_attempts);
-		fprintf(fp, "normal_check_interval=%f\n", temp_service->check_interval);
-		fprintf(fp, "retry_check_interval=%f\n", temp_service->retry_interval);
+		fprintf(fp, "check_interval=%f\n", temp_service->check_interval);
+		fprintf(fp, "retry_interval=%f\n", temp_service->retry_interval);
 		fprintf(fp, "state_type=%d\n", temp_service->state_type);
-		fprintf(fp, "last_state_change=%lu\n", temp_service->last_state_change);
-		fprintf(fp, "last_hard_state_change=%lu\n", temp_service->last_hard_state_change);
-		fprintf(fp, "last_time_ok=%lu\n", temp_service->last_time_ok);
-		fprintf(fp, "last_time_warning=%lu\n", temp_service->last_time_warning);
-		fprintf(fp, "last_time_unknown=%lu\n", temp_service->last_time_unknown);
-		fprintf(fp, "last_time_critical=%lu\n", temp_service->last_time_critical);
+		fprintf(fp, "last_state_change=%llu\n", (unsigned long long)temp_service->last_state_change);
+		fprintf(fp, "last_hard_state_change=%llu\n", (unsigned long long)temp_service->last_hard_state_change);
+		fprintf(fp, "last_time_ok=%llu\n", (unsigned long long)temp_service->last_time_ok);
+		fprintf(fp, "last_time_warning=%llu\n", (unsigned long long)temp_service->last_time_warning);
+		fprintf(fp, "last_time_unknown=%llu\n", (unsigned long long)temp_service->last_time_unknown);
+		fprintf(fp, "last_time_critical=%llu\n", (unsigned long long)temp_service->last_time_critical);
 		fprintf(fp, "plugin_output=%s\n", (temp_service->plugin_output == NULL) ? "" : temp_service->plugin_output);
 		fprintf(fp, "long_plugin_output=%s\n", (temp_service->long_plugin_output == NULL) ? "" : temp_service->long_plugin_output);
 		fprintf(fp, "performance_data=%s\n", (temp_service->perf_data == NULL) ? "" : temp_service->perf_data);
-		fprintf(fp, "last_check=%lu\n", temp_service->last_check);
-		fprintf(fp, "next_check=%lu\n", temp_service->next_check);
+		fprintf(fp, "last_check=%llu\n", (unsigned long long)temp_service->last_check);
+		fprintf(fp, "next_check=%llu\n", (unsigned long long)temp_service->next_check);
 		fprintf(fp, "check_options=%d\n", temp_service->check_options);
 		fprintf(fp, "notified_on_unknown=%d\n", flag_isset(temp_service->notified_on, OPT_UNKNOWN));
 		fprintf(fp, "notified_on_warning=%d\n", flag_isset(temp_service->notified_on, OPT_WARNING));
 		fprintf(fp, "notified_on_critical=%d\n", flag_isset(temp_service->notified_on, OPT_CRITICAL));
 		fprintf(fp, "current_notification_number=%d\n", temp_service->current_notification_number);
 		fprintf(fp, "current_notification_id=%lu\n", temp_service->current_notification_id);
-		fprintf(fp, "last_notification=%lu\n", temp_service->last_notification);
+		fprintf(fp, "last_notification=%llu\n", (unsigned long long)temp_service->last_notification);
 		fprintf(fp, "notifications_enabled=%d\n", temp_service->notifications_enabled);
 		fprintf(fp, "active_checks_enabled=%d\n", temp_service->checks_enabled);
 		fprintf(fp, "passive_checks_enabled=%d\n", temp_service->accept_passive_checks);
@@ -336,8 +336,8 @@ int xrddefault_save_state_information(void) {
 		fprintf(fp, "modified_service_attributes=%lu\n", (temp_contact->modified_service_attributes & ~contact_service_attribute_mask));
 		fprintf(fp, "host_notification_period=%s\n", (temp_contact->host_notification_period == NULL) ? "" : temp_contact->host_notification_period);
 		fprintf(fp, "service_notification_period=%s\n", (temp_contact->service_notification_period == NULL) ? "" : temp_contact->service_notification_period);
-		fprintf(fp, "last_host_notification=%lu\n", temp_contact->last_host_notification);
-		fprintf(fp, "last_service_notification=%lu\n", temp_contact->last_service_notification);
+		fprintf(fp, "last_host_notification=%llu\n", (unsigned long long)temp_contact->last_host_notification);
+		fprintf(fp, "last_service_notification=%llu\n", (unsigned long long)temp_contact->last_service_notification);
 		fprintf(fp, "host_notifications_enabled=%d\n", temp_contact->host_notifications_enabled);
 		fprintf(fp, "service_notifications_enabled=%d\n", temp_contact->service_notifications_enabled);
 
@@ -364,9 +364,9 @@ int xrddefault_save_state_information(void) {
 		fprintf(fp, "comment_id=%lu\n", temp_comment->comment_id);
 		fprintf(fp, "source=%d\n", temp_comment->source);
 		fprintf(fp, "persistent=%d\n", temp_comment->persistent);
-		fprintf(fp, "entry_time=%lu\n", temp_comment->entry_time);
+		fprintf(fp, "entry_time=%llu\n", (unsigned long long)temp_comment->entry_time);
 		fprintf(fp, "expires=%d\n", temp_comment->expires);
-		fprintf(fp, "expire_time=%lu\n", temp_comment->expire_time);
+		fprintf(fp, "expire_time=%llu\n", (unsigned long long)temp_comment->expire_time);
 		fprintf(fp, "author=%s\n", temp_comment->author);
 		fprintf(fp, "comment_data=%s\n", temp_comment->comment_data);
 		fprintf(fp, "}\n");
@@ -384,10 +384,10 @@ int xrddefault_save_state_information(void) {
 			fprintf(fp, "service_description=%s\n", temp_downtime->service_description);
 		fprintf(fp, "comment_id=%lu\n", temp_downtime->comment_id);
 		fprintf(fp, "downtime_id=%lu\n", temp_downtime->downtime_id);
-		fprintf(fp, "entry_time=%lu\n", temp_downtime->entry_time);
-		fprintf(fp, "start_time=%lu\n", temp_downtime->start_time);
-		fprintf(fp, "flex_downtime_start=%lu\n", temp_downtime->flex_downtime_start);
-		fprintf(fp, "end_time=%lu\n", temp_downtime->end_time);
+		fprintf(fp, "entry_time=%llu\n", (unsigned long long)temp_downtime->entry_time);
+		fprintf(fp, "start_time=%llu\n", (unsigned long long)temp_downtime->start_time);
+		fprintf(fp, "flex_downtime_start=%llu\n", (unsigned long long)temp_downtime->flex_downtime_start);
+		fprintf(fp, "end_time=%llu\n", (unsigned long long)temp_downtime->end_time);
 		fprintf(fp, "triggered_by=%lu\n", temp_downtime->triggered_by);
 		fprintf(fp, "fixed=%d\n", temp_downtime->fixed);
 		fprintf(fp, "duration=%lu\n", temp_downtime->duration);
@@ -770,7 +770,7 @@ int xrddefault_read_state_information(void) {
 							remove_comment = TRUE;
 						}
 					/* non-persistent comments don't last past restarts UNLESS they're acks (see above) */
-					else if(persistent == FALSE)
+					else if(persistent == FALSE && (sigrestart == FALSE || entry_type == DOWNTIME_COMMENT))
 						remove_comment = TRUE;
 
 					if(remove_comment == TRUE)
@@ -1039,7 +1039,7 @@ int xrddefault_read_state_information(void) {
 									temp_host->check_options = atoi(val);
 								}
 							else if(!strcmp(var, "current_attempt"))
-								temp_host->current_attempt = (atoi(val) > 0) ? TRUE : FALSE;
+								temp_host->current_attempt = atoi(val);
 							else if(!strcmp(var, "current_event_id"))
 								temp_host->current_event_id = strtoul(val, NULL, 10);
 							else if(!strcmp(var, "last_event_id"))
@@ -1191,11 +1191,11 @@ int xrddefault_read_state_information(void) {
 										temp_host->modified_attributes -= MODATTR_EVENT_HANDLER_COMMAND;
 									}
 								}
-							else if(!strcmp(var, "normal_check_interval")) {
+							else if(!strcmp(var, "check_interval")) {
 								if(temp_host->modified_attributes & MODATTR_NORMAL_CHECK_INTERVAL && strtod(val, NULL) >= 0)
 									temp_host->check_interval = strtod(val, NULL);
 								}
-							else if(!strcmp(var, "retry_check_interval")) {
+							else if(!strcmp(var, "retry_interval")) {
 								if(temp_host->modified_attributes & MODATTR_RETRY_CHECK_INTERVAL && strtod(val, NULL) >= 0)
 									temp_host->retry_interval = strtod(val, NULL);
 								}
@@ -1462,11 +1462,11 @@ int xrddefault_read_state_information(void) {
 										temp_service->modified_attributes -= MODATTR_EVENT_HANDLER_COMMAND;
 									}
 								}
-							else if(!strcmp(var, "normal_check_interval")) {
+							else if(!strcmp(var, "check_interval")) {
 								if(temp_service->modified_attributes & MODATTR_NORMAL_CHECK_INTERVAL && strtod(val, NULL) >= 0)
 									temp_service->check_interval = strtod(val, NULL);
 								}
-							else if(!strcmp(var, "retry_check_interval")) {
+							else if(!strcmp(var, "retry_interval")) {
 								if(temp_service->modified_attributes & MODATTR_RETRY_CHECK_INTERVAL && strtod(val, NULL) >= 0)
 									temp_service->retry_interval = strtod(val, NULL);
 								}
