@@ -237,6 +237,7 @@ int xsddefault_save_status_data(void) {
 		fprintf(fp, "\tcheck_command=%s\n", (temp_host->check_command == NULL) ? "" : temp_host->check_command);
 		fprintf(fp, "\tcheck_period=%s\n", (temp_host->check_period == NULL) ? "" : temp_host->check_period);
 		fprintf(fp, "\tnotification_period=%s\n", (temp_host->notification_period == NULL) ? "" : temp_host->notification_period);
+		fprintf(fp, "\timportance=%u\n", temp_host->hourly_value);
 		fprintf(fp, "\tcheck_interval=%f\n", temp_host->check_interval);
 		fprintf(fp, "\tretry_interval=%f\n", temp_host->retry_interval);
 		fprintf(fp, "\tevent_handler=%s\n", (temp_host->event_handler == NULL) ? "" : temp_host->event_handler);
@@ -303,6 +304,7 @@ int xsddefault_save_status_data(void) {
 		fprintf(fp, "\tcheck_command=%s\n", (temp_service->check_command == NULL) ? "" : temp_service->check_command);
 		fprintf(fp, "\tcheck_period=%s\n", (temp_service->check_period == NULL) ? "" : temp_service->check_period);
 		fprintf(fp, "\tnotification_period=%s\n", (temp_service->notification_period == NULL) ? "" : temp_service->notification_period);
+		fprintf(fp, "\timportance=%u\n", temp_service->hourly_value);
 		fprintf(fp, "\tcheck_interval=%f\n", temp_service->check_interval);
 		fprintf(fp, "\tretry_interval=%f\n", temp_service->retry_interval);
 		fprintf(fp, "\tevent_handler=%s\n", (temp_service->event_handler == NULL) ? "" : temp_service->event_handler);
@@ -510,6 +512,7 @@ int xsddefault_read_status_data(const char *status_file_name, int options) {
 	char *service_description = NULL;
 	char *author = NULL;
 	char *comment_data = NULL;
+	scheduled_downtime *temp_downtime;
 	unsigned long downtime_id = 0;
 	time_t start_time = 0L;
 	time_t flex_downtime_start = 0L;
@@ -640,10 +643,16 @@ int xsddefault_read_status_data(const char *status_file_name, int options) {
 				case XSDDEFAULT_SERVICEDOWNTIME_DATA:
 
 					/* add the downtime */
-					if(data_type == XSDDEFAULT_HOSTDOWNTIME_DATA)
+					if(data_type == XSDDEFAULT_HOSTDOWNTIME_DATA) {
 						add_host_downtime(host_name, entry_time, author, comment_data, start_time, flex_downtime_start, end_time, fixed, triggered_by, duration, downtime_id, is_in_effect, start_notification_sent);
-					else
+						temp_downtime = find_downtime(HOST_DOWNTIME, downtime_id);
+					} else {
 						add_service_downtime(host_name, service_description, entry_time, author, comment_data, start_time, flex_downtime_start, end_time, fixed, triggered_by, duration, downtime_id, is_in_effect, start_notification_sent);
+						temp_downtime = find_downtime(SERVICE_DOWNTIME, downtime_id);
+					}
+
+					if (temp_downtime)
+						temp_downtime->comment_id = comment_id;
 
 					/* free temp memory */
 					my_free(host_name);
@@ -653,6 +662,7 @@ int xsddefault_read_status_data(const char *status_file_name, int options) {
 
 					/* reset defaults */
 					downtime_id = 0;
+					comment_id = 0;
 					entry_time = 0L;
 					start_time = 0L;
 					end_time = 0L;
@@ -796,8 +806,6 @@ int xsddefault_read_status_data(const char *status_file_name, int options) {
 							temp_hoststatus->next_check = strtoul(val, NULL, 10);
 						else if(!strcmp(var, "check_options"))
 							temp_hoststatus->check_options = atoi(val);
-						else if(!strcmp(var, "current_attempt"))
-							temp_hoststatus->current_attempt = (atoi(val) > 0) ? TRUE : FALSE;
 						else if(!strcmp(var, "state_type"))
 							temp_hoststatus->state_type = atoi(val);
 						else if(!strcmp(var, "last_state_change"))
